#! /bin/bash
###############################################################################
# Licensed Materials - Property of IBM
# (c) Copyright IBM Corporation 2001, 2016. All Rights Reserved.
#
# Note to U.S. Government Users Restricted Rights:  
# Use, duplication or disclosure restricted by GSA ADP Schedule 
# Contract with IBM Corp. 
###############################################################################
#----------------------------------------------------------------------
#  Description  :   Configure permissions for MQ objects required by RIT for
#                   use when recording using the exit.
#                   The knowledge center should be consulted for more information
#                   on all required permissions.
#
#  Usage        :   See Usage() below.
#
#  Requirements :   run this as 'mqm' on the linux machine that hosts the
#                   queue manager
#----------------------------------------------------------------------
#
#######################################################################
#
#       Environment.
#
#######################################################################

#
#       Program variables.
#
ProgName="${0##*/}"
YYYYMMDD=$(date "+%Y-%m-%d")

#######################################################################
#
#       Function declarations.
#
#######################################################################
#

Usage()
{
    echo
    echo "
Usage:  $ProgName [-gv]  qmName RITEntity puttingAppEntity [mirrorQPrefix]

    where
    -g  
        Group mode. Set permissions for groups instead of users.  Defaults to
        setting permissions for users. (Optional)
        
    -v
        Verbose mode. Echoes the actions being performed by the script. (Optional)
        
    qmName  
        The name of the local queue manager to configure
        
    RITEntity  
        The user ID configured in physical resources in Rational Integration
        Tester or, the group to which the user belongs
        
    puttingAppEntity  
        The userID used by application putting messages onto MQ queues or,
        name of the group to which the user belongs
        
    mirrorQPrefix  
        The prefix for mirror queues specified in the recording tab of the
        physical transport.  Defaults to blank. (Optional)

"
}

log() 
{
    if [ $verbose -eq 1 ]
    then
        echo "$1"
    fi
}

#
#######################################################################
#
#       Main processing starts here.
#
#######################################################################
#

#
#   Use getopts to parse the command line arguments.
#
verbose=0
entityType="-p"

while getopts gv ch
do
    case $ch in
        g)  entityType="-g"
            ;;
        v)  verbose=1;
            ;;
        *)  Usage
            status=1
            exit $status
            ;;
    esac
done

if [ $verbose -eq 0 ]
then
    exec 2>/dev/null
fi

if [ "$entityType" = "-g" ]
then
    log "Applying permissions to groups"
fi

shift $(expr $OPTIND - 1)

if [ $# -lt 3 ]
then
    Usage
    status=1
    exit $status
fi

status=0

qmName=$1
ritEntity="$2"
puttingAppEntity=$3
mirrorQPrefix=$4

# Dump all existing queue manager authorities to file prior to running the setmqaut commands

log "Backing up current permissions for MQ entity configured in RIT: $ritEntity"
log "dmpmqaut -m $qmName $entityType $ritEntity >| $YYYYMMDD-$ProgName-ritEntity.aut 2>&1"
dmpmqaut -m $qmName $entityType $ritEntity >| $YYYYMMDD-$ProgName-ritEntity.aut 2>&1
status=$?
if [ $status -ne 0 ]
then
    echo "Error: dmpmqaut failure, could not back up existing object permissions for RIT entity. Aborting."
    exit $status
fi

log "Backing up current permissions for MQ entity for the putting application: $puttingAppEntity"
log "dmpmqaut -m $qmName $entityType $puttingAppEntity >| $YYYYMMDD-$ProgName-puttingAppEntity.aut 2>&1"
dmpmqaut -m $qmName $entityType $puttingAppEntity >| $YYYYMMDD-$ProgName-puttingAppEntity.aut 2>&1
status=$?
if [ $status -ne 0 ]
then
    echo "Error: dmpmqaut failure, could not back up existing object permissions for putting app entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t qmgr $entityType $ritEntity +connect +inq +dsp"
setmqaut -m $qmName -t qmgr $entityType $ritEntity +connect +inq +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failed applying Queue manager permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n SYSTEM.DEFAULT.MODEL.QUEUE $entityType $ritEntity +get +dsp"
setmqaut -m $qmName -t q -n SYSTEM.DEFAULT.MODEL.QUEUE $entityType $ritEntity +get +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.DEFAULT.MODEL.QUEUE permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t q -n SYSTEM.ADMIN.COMMAND.QUEUE $entityType $ritEntity +inq +put"
setmqaut -m $qmName -t q -n SYSTEM.ADMIN.COMMAND.QUEUE $entityType $ritEntity +inq +put
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.ADMIN.COMMAND.QUEUE permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n SYSTEM.DEFAULT.NAMELIST -t namelist $entityType $ritEntity +dsp"
setmqaut -m $qmName -n SYSTEM.DEFAULT.NAMELIST -t namelist $entityType $ritEntity +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.DEFAULT.NAMELIST permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "**" -t namelist $entityType $ritEntity +crt"
setmqaut -m $qmName -n "**" -t namelist $entityType $ritEntity +crt
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying namelist create permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "com.greenhat.intercept*" -t namelist $entityType $ritEntity +dsp +chg"
setmqaut -m $qmName -n "com.greenhat.intercept*" -t namelist $entityType $ritEntity +dsp +chg
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying general recording namelist permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t qmgr $entityType $puttingAppEntity +connect +inq +setall"
setmqaut -m $qmName -t qmgr $entityType $puttingAppEntity +connect +inq +setall
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying queue manager permissions for putting application entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "com.greenhat.intercept*" -t namelist $entityType $puttingAppEntity +inq"
setmqaut -m $qmName -n "com.greenhat.intercept*" -t namelist $entityType $puttingAppEntity +inq
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying general recording namelist permissions for putting application entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "AMQ.$mirrorQPrefix**" -t q $entityType "$puttingAppEntity" +put +setall"
setmqaut -m $qmName -n "AMQ.$mirrorQPrefix**" -t q $entityType "$puttingAppEntity" +put +setall
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying general temporary recording queue permissions for putting application entity. Aborting."
    exit $status
fi

echo "All permissions successfully applied"

exit $status
