#! /bin/bash
###############################################################################
# Licensed Materials - Property of IBM
# (c) Copyright IBM Corporation 2001, 2016. All Rights Reserved.
#
# Note to U.S. Government Users Restricted Rights:  
# Use, duplication or disclosure restricted by GSA ADP Schedule 
# Contract with IBM Corp. 
###############################################################################
#----------------------------------------------------------------------
#  Description  :   Configure permissions for MQ objects required by RIT for
#                   use when stubbing using the exit with fixed queues mode.
#                   The knowledge center should be consulted for more information
#                   on all required permissions.
#
#  Usage        :   See Usage() below.
#
#  Requirements :   run this as 'mqm' on the linux machine that hosts the
#                   queue manager
#----------------------------------------------------------------------
#
#######################################################################
#
#       Environment.
#
#######################################################################
#
#   Store standard errors in a temporary file.
#

#
#       Program variables.
#
ProgName="${0##*/}"
YYYYMMDD=$(date "+%Y-%m-%d")

#
#######################################################################
#
#       Function declarations.
#
#######################################################################
#

Usage()
{
    echo
    echo "
Usage:  $ProgName [-gv] qmName RITEntity puttingAppEntity stubbedQName [responseQName] [stubQSuffix] [divertQSuffix]

    where
    -g  
        Group mode. Set permissions for groups instead of users.  Defaults to
        setting permissions for users. (Optional)
        
    -v
        Verbose mode. Echoes the actions being performed by the script. (Optional)

    qmName
        The name of the local queue manager to configure

    RITEntity
          The user ID configured in the physical resources in Rational
          Integration Tester or, the name of a group to which the user belongs

    puttingAppEntity
          The user ID used by the application putting messages onto MQ queues
          or, the name of a group to which the user belongs

    stubbedQName
          The name of the queue from which the Stub will read messages
          
    responseQName
          The name of the queue on which stubbed messages should be placed.
          (Optional)

    stubQSuffix (default: .STUB)
          Suffix applied to stubbed queue name to get the name of the stub
          queue used to store temporary messages by the exit. Configured in
          the 'Stubbing' tab of the MQ physical transport. (Optional)

    divertQSuffix (default: .DIVERT)
          Suffix applied to stubbed queue name to get the name of the divert
          queue used to store temporary messages by the exit. Configured in
          the 'Stubbing' tab of the MQ physical transport. (Optional)

" | more
}

log() 
{
    if [ $verbose -eq 1 ]
    then
        echo "$1"
    fi
}

#
#######################################################################
#
#       Main processing starts here.
#
#######################################################################
#

#
#   Use getopts to parse the command line arguments.
#
verbose=0
entityType="-p"
stubQSuffix=".STUB"
divertQSuffix=".DIVERT"

while getopts gv ch
do
    case $ch in
        g)  entityType="-g"
            ;;
        v)  verbose=1;
            ;;
        *)  Usage
            status=1
            exit $status
            ;;
    esac
done

if [ $verbose -eq 0 ]
then
    exec 2>/dev/null
fi

if [ "$entityType" = "-g" ]
then
    log "Applying permissions to groups"
fi

shift $(expr $OPTIND - 1)

if [ $# -lt 4 ]
then
    Usage
    status=1
    exit $status
fi

status=0

qmName=$1
RITEntity="$2"
puttingAppEntity=$3
stubbedQName=$4
responseQName=$5
stubQSuffix=${6:-$stubQSuffix}
divertQSuffix=${7:-$divertQSuffix}

# Dump all existing queue manager authorities to file prior to running the setmqaut commands

log "Backing up current permissions for MQ entity configured in RIT: $RITEntity"
log "dmpmqaut -m $qmName $entityType $RITEntity >| $YYYYMMDD-$ProgName-ritEntity.aut 2>&1"
dmpmqaut -m $qmName $entityType $RITEntity >| $YYYYMMDD-$ProgName-ritEntity.aut 2>&1
status=$?
if [ $status -ne 0 ]
then
    echo "Error: dmpmqaut failure, could not back up existing object permissions for RIT entity. Aborting."
    exit $status
fi

log "Backing up current permissions for MQ entity for the putting application: $puttingAppEntity"
log "dmpmqaut -m $qmName $entityType $puttingAppEntity >| $YYYYMMDD-$ProgName-puttingAppEntity.aut 2>&1"
dmpmqaut -m $qmName $entityType $puttingAppEntity >| $YYYYMMDD-$ProgName-puttingAppEntity.aut 2>&1
status=$?
if [ $status -ne 0 ]
then
    echo "Error: dmpmqaut failure, could not back up existing object permissions for putting app entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t qmgr $entityType "$RITEntity" +connect +inq +dsp +setall"
setmqaut -m $qmName -t qmgr $entityType "$RITEntity" +connect +inq +dsp +setall
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying Queue manager permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "rit.divert.rules*" -t namelist $entityType "$RITEntity" +chg +inq +dsp"
setmqaut -m $qmName -n "rit.divert.rules*" -t namelist $entityType "$RITEntity" +chg +inq +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying general divert namelist permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n $stubbedQName -t q $entityType "$RITEntity" +put +setall"
setmqaut -m $qmName -n $stubbedQName -t q $entityType "$RITEntity" +put +setall
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying stubbed queue permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n SYSTEM.ADMIN.COMMAND.QUEUE -t q $entityType "$RITEntity" +put +inq"
setmqaut -m $qmName -n SYSTEM.ADMIN.COMMAND.QUEUE -t q $entityType "$RITEntity" +put +inq
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.ADMIN.COMMAND.QUEUE permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n SYSTEM.DEFAULT.MODEL.QUEUE -t q $entityType "$RITEntity" +get +dsp"
setmqaut -m $qmName -n SYSTEM.DEFAULT.MODEL.QUEUE -t q $entityType "$RITEntity" +get +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.DEFAULT.MODEL.QUEUE permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n SYSTEM.DEFAULT.NAMELIST -t namelist $entityType "$RITEntity" +dsp"
setmqaut -m $qmName -n SYSTEM.DEFAULT.NAMELIST -t namelist $entityType "$RITEntity" +dsp
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying SYSTEM.DEFAULT.NAMELIST permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "**" -t namelist $entityType "$RITEntity" +crt"
setmqaut -m $qmName -n "**" -t namelist $entityType "$RITEntity" +crt
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying namelist create permissions for RIT entity. Aborting."
    exit $status
fi

if [ -n "$responseQName" ]
then
    log "setmqaut -m $qmName -n "$responseQName" -t q $entityType "$RITEntity" +put"
    setmqaut -m $qmName -n "$responseQName" -t q $entityType "$RITEntity" +put
    status=$?
    if [ $status -ne 0 ]
    then
        echo "Error: Failure applying response queue permissions for RIT entity. Aborting."
        exit $status
    fi
else
    log "Not applying response queue permissions as no response queue was specified."
fi

log "setmqaut -m $qmName -n "$stubbedQName$stubQSuffix" -t q $entityType "$RITEntity" +get"
setmqaut -m $qmName -n "$stubbedQName$stubQSuffix" -t q $entityType "$RITEntity" +get
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying fixed stub queue permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "$stubbedQName$divertQSuffix" -t q $entityType "$RITEntity" +get +put"
setmqaut -m $qmName -n "$stubbedQName$divertQSuffix" -t q $entityType "$RITEntity" +get +put
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying fixed divert queue permissions for RIT entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -t qmgr $entityType "$puttingAppEntity" +connect +inq"
setmqaut -m $qmName -t qmgr $entityType "$puttingAppEntity" +connect +inq
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying queue manager permissions for putting application entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "rit.divert.rules*" -t namelist $entityType "$puttingAppEntity" +inq"
setmqaut -m $qmName -n "rit.divert.rules*" -t namelist $entityType "$puttingAppEntity" +inq
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying general divert namelist permissions for putting application entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "$stubbedQName$stubQSuffix" -t q $entityType "$puttingAppEntity" +put"
setmqaut -m $qmName -n "$stubbedQName$stubQSuffix" -t q $entityType "$puttingAppEntity" +put
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying fixed stub queue permissions for putting application entity. Aborting."
    exit $status
fi

log "setmqaut -m $qmName -n "$stubbedQName$divertQSuffix" -t q $entityType "$puttingAppEntity" +get +put"
setmqaut -m $qmName -n "$stubbedQName$divertQSuffix" -t q $entityType "$puttingAppEntity" +get +put
status=$?
if [ $status -ne 0 ]
then
    echo "Error: Failure applying fixed divert queue permissions for putting application entity. Aborting."
    exit $status
fi

echo "All permissions successfully applied"

exit $status
